==> kadu-0.3.9.tar.bz2: kadu/modules/default_sms/translations/default_sms_de.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
    <message>
        <source>SMS Era Gateway</source>
        <translation>SMS-Gateway vom Era GSM</translation>
    </message>
    <message>
        <source>User ID</source>
        <translation>Benutzer-ID</translation>
    </message>
    <message>
        <source>Type of gateway</source>
        <translation>Typ des Gateways</translation>
    </message>
</context>
<context>
    <name>SmsEraGateway</name>
    <message>
        <source>Provider gateway results page looks strange. SMS was probably NOT sent.</source>
        <translation>Die Antwort des SMS-Gateways ist seltsam. SMS wurde wahrscheinlich nicht verschickt.</translation>
    </message>
    <message>
        <source>Error: </source>
        <translation>Fehler:</translation>
    </message>
    <message>
        <source>No error</source>
        <translation>Keine Fehler</translation>
    </message>
    <message>
        <source>System failure</source>
        <translation>Systemfehler</translation>
    </message>
    <message>
        <source>Unauthorised user</source>
        <translation>Nicht zugelassener Benutzer</translation>
    </message>
    <message>
        <source>Access forbidden</source>
        <translation>Zugriff verboten</translation>
    </message>
    <message>
        <source>Syntax error</source>
        <translation>Syntax-Fehler</translation>
    </message>
    <message>
        <source>Limit of the sms run-down</source>
        <translation>Verbleibende freie Zeichen</translation>
    </message>
    <message>
        <source>Wrong receiver adress</source>
        <translation>falsche Empfängeradresse</translation>
    </message>
    <message>
        <source>Message too long</source>
        <translation>Nachricht zu lang</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Unbekannter Fehler</translation>
    </message>
</context>
<context>
    <name>SmsIdeaGateway</name>
    <message>
        <source>Provider gateway page looks strange. It&apos;s probably temporary disabled
or has beed changed too much to parse it correctly.</source>
        <translation>SMS-Gateway ist unerreichbar. Wahrscheinlich ist sie momentan ausgeschaltet
oder änderte die Zugangserlaubnis.</translation>
    </message>
    <message>
        <source>You exceeded your daily limit</source>
        <translation>SMS-Limit überschritten</translation>
    </message>
    <message>
        <source>Text from the picture is incorrect</source>
        <translation>Der vom Bild abgelesene Text ist falsch</translation>
    </message>
    <message>
        <source>The receiver has to enable SMS STANDARD service</source>
        <translation>Der Empfänger hat den Dienst SMS STANDARD nicht eingeschaltet</translation>
    </message>
    <message>
        <source>Provider gateway results page looks strange. SMS was probably NOT sent.</source>
        <translation>Die Antwort des SMS-Gateways ist seltsam. SMS wurde wahrscheinlich nicht verschickt.</translation>
    </message>
</context>
<context>
    <name>SmsPlusGateway</name>
    <message>
        <source>Provider gateway page looks strange. It&apos;s probably temporary disabled
or has beed changed too much to parse it correctly.</source>
        <translation>SMS-Gateway ist unerreichbar. Wahrscheinlich ist sie momentan ausgeschaltet
oder änderte die Zugangserlaubnis.</translation>
    </message>
    <message>
        <source>Provider gateway results page looks strange. SMS was probably NOT sent.</source>
        <translation>Die Antwort des SMS-Gateways ist seltsam. SMS wurde wahrscheinlich nicht verschickt.</translation>
    </message>
</context>
</TS>

==> kadu-0.4.1.tar.bz2: kadu/modules/default_sms/translations/default_sms_de.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
    <message>
        <source>SMS Era Gateway</source>
        <translation>SMS-Gateway vom Era GSM</translation>
    </message>
    <message>
        <source>Type of gateway</source>
        <translation>Typ des Gateways</translation>
    </message>
    <message>
        <source>User ID (48xxxxxxxxx)</source>
        <translation>Benutzer ID (48xxxxxxxx)</translation>
    </message>
</context>
<context>
    <name>SmsEraGateway</name>
    <message>
        <source>Provider gateway results page looks strange. SMS was probably NOT sent.</source>
        <translation>Die Antwort des SMS-Gateways ist seltsam. SMS wurde wahrscheinlich nicht verschickt.</translation>
    </message>
    <message>
        <source>Error: </source>
        <translation>Fehler:</translation>
    </message>
    <message>
        <source>No error</source>
        <translation>Keine Fehler</translation>
    </message>
    <message>
        <source>System failure</source>
        <translation>Systemfehler</translation>
    </message>
    <message>
        <source>Unauthorised user</source>
        <translation>Nicht zugelassener Benutzer</translation>
    </message>
    <message>
        <source>Access forbidden</source>
        <translation>Zugriff verboten</translation>
    </message>
    <message>
        <source>Syntax error</source>
        <translation>Syntax-Fehler</translation>
    </message>
    <message>
        <source>Limit of the sms run-down</source>
        <translation>Verbleibende freie Zeichen</translation>
    </message>
    <message>
        <source>Message too long</source>
        <translation>Nachricht zu lang</translation>
    </message>
    <message>
        <source>Wrong receiver address</source>
        <translation>Unbekannte Empfängeradresse</translation>
    </message>
    <message>
        <source>Unknown error (%1)</source>
        <translation>Unbekannter Fehler (%1)</translation>
    </message>
</context>
<context>
    <name>SmsIdeaGateway</name>
    <message>
        <source>Provider gateway page looks strange. It&apos;s probably temporary disabled
or has beed changed too much to parse it correctly.</source>
        <translation>SMS-Gateway ist unerreichbar. Wahrscheinlich ist sie momentan ausgeschaltet
oder änderte die Zugangserlaubnis.</translation>
    </message>
    <message>
        <source>You exceeded your daily limit</source>
        <translation>SMS-Limit überschritten</translation>
    </message>
    <message>
        <source>Text from the picture is incorrect</source>
        <translation>Der vom Bild abgelesene Text ist falsch</translation>
    </message>
    <message>
        <source>The receiver has to enable SMS STANDARD service</source>
        <translation>Der Empfänger hat den Dienst SMS STANDARD nicht eingeschaltet</translation>
    </message>
    <message>
        <source>Provider gateway results page looks strange. SMS was probably NOT sent.</source>
        <translation>Die Antwort des SMS-Gateways ist seltsam. SMS wurde wahrscheinlich nicht verschickt.</translation>
    </message>
</context>
<context>
    <name>SmsPlusGateway</name>
    <message>
        <source>Provider gateway page looks strange. It&apos;s probably temporary disabled
or has beed changed too much to parse it correctly.</source>
        <translation>SMS-Gateway ist unerreichbar. Wahrscheinlich ist sie momentan ausgeschaltet
oder änderte die Zugangserlaubnis.</translation>
    </message>
    <message>
        <source>Provider gateway results page looks strange. SMS was probably NOT sent.</source>
        <translation>Die Antwort des SMS-Gateways ist seltsam. SMS wurde wahrscheinlich nicht verschickt.</translation>
    </message>
    <message>
        <source>Limits have been exceeded, try again later.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
